![cobry](https://user-images.githubusercontent.com/18513179/85131728-a9cdbe80-b237-11ea-9804-48ed1537e609.png)

Cobry is a library for creating powerful and modern CLI applications by providing a simple to follow architecture. It helps you to create clean and easy to use CLI applications like git, kubectl or helm.

On further notice, cobry is a python port (WIP) of the popular GOlang CLI creation library [cobra](https://github.com/spf13/cobra). It aims to be as versatile as the original library and brings the clean architecture and concepts defined for cobra into the python ecosystem.


[![Build Status](https://travis-ci.org/tuunit/cobry.svg?branch=master)](https://travis-ci.org/tuunit/cobry)
[![Coverage Status](https://coveralls.io/repos/github/tuunit/cobry/badge.svg?branch=master)](https://coveralls.io/github/tuunit/cobry?branch=master)
![PyPI - Downloads](https://img.shields.io/pypi/dm/cobry)
![PyPI - License](https://img.shields.io/pypi/l/cobry)
